Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Honeycode.

Actions, resources, and condition keys for Amazon Honeycode - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Honeycode

Amazon Honeycode (service prefix: `honeycode` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon Honeycode
- Resource types defined by Amazon Honeycode
- Condition keys for Amazon Honeycode

## Actions defined by Amazon Honeycode

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
ApproveTeamAssociation [permission only] | Grants permission to approve a team association request for your AWS Account | Write |  |  |
BatchCreateTableRows | Grants permission to create new rows in a table | Write | table* |  |
BatchDeleteTableRows | Grants permission to delete rows from a table | Write | table* |  |
BatchUpdateTableRows | Grants permission to update rows in a table | Write | table* |  |
BatchUpsertTableRows | Grants permission to upsert rows in a table | Write | table* |  |
CreateTeam [permission only] | Grants permission to create a new Amazon Honeycode team for your AWS Account | Write |  |  |
CreateTenant [permission only] | Grants permission to create a new tenant within Amazon Honeycode for your AWS Account | Write |  |  |
DeleteDomains [permission only] | Grants permission to delete Amazon Honeycode domains for your AWS Account | Write |  |  |
DeregisterGroups [permission only] | Grants permission to remove groups from an Amazon Honeycode team for your AWS Account | Write |  |  |
DescribeTableDataImportJob | Grants permission to get details about a table data import job | Read | table* |  |
DescribeTeam [permission only] | Grants permission to get details about Amazon Honeycode teams for your AWS Account | Read |  |  |
GetScreenData | Grants permission to load the data from a screen | Read | screen* |  |
InvokeScreenAutomation | Grants permission to invoke a screen automation | Write | screen-automation* |  |
ListDomains [permission only] | Grants permission to list all Amazon Honeycode domains and their verification status for your AWS Account | List |  |  |
ListGroups [permission only] | Grants permission to list all groups in an Amazon Honeycode team for your AWS Account | List |  |  |
ListTableColumns | Grants permission to list the columns in a table | List | table* |  |
ListTableRows | Grants permission to list the rows in a table | List | table* |  |
ListTables | Grants permission to list the tables in a workbook | List | workbook* |  |
ListTagsForResource | Grants permission to list all tags for a resource | Tagging |  |  |
ListTeamAssociations [permission only] | Grants permission to list all pending and approved team associations with your AWS Account | List |  |  |
ListTenants [permission only] | Grants permission to list all tenants of Amazon Honeycode for your AWS Account | List |  |  |
QueryTableRows | Grants permission to query the rows of a table using a filter | Read | table* |  |
RegisterDomainForVerification [permission only] | Grants permission to request verification of the Amazon Honeycode domains for your AWS Account | Write |  |  |
RegisterGroups [permission only] | Grants permission to add groups to an Amazon Honeycode team for your AWS Account | Write |  |  |
RejectTeamAssociation [permission only] | Grants permission to reject a team association request for your AWS Account | Write |  |  |
RestartDomainVerification [permission only] | Grants permission to restart verification of the Amazon Honeycode domains for your AWS Account | Write |  |  |
StartTableDataImportJob | Grants permission to start a table data import job | Write | table* |  |
TagResource | Grants permission to tag a resource | Tagging |  |  |
UntagResource | Grants permission to untag a resource | Tagging |  |  |
UpdateTeam [permission only] | Grants permission to update an Amazon Honeycode team for your AWS Account | Write |  |  |

## Resource types defined by Amazon Honeycode

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
workbook | `arn:$ { Partition}:honeycode:$ { Region}:$ { Account}:workbook:workbook/$ { WorkbookId}` |
table | `arn:$ { Partition}:honeycode:$ { Region}:$ { Account}:table:workbook/$ { WorkbookId}/table/$ { TableId}` |
screen | `arn:$ { Partition}:honeycode:$ { Region}:$ { Account}:screen:workbook/$ { WorkbookId}/app/$ { AppId}/screen/$ { ScreenId}` |
screen-automation | `arn:$ { Partition}:honeycode:$ { Region}:$ { Account}:screen-automation:workbook/$ { WorkbookId}/app/$ { AppId}/screen/$ { ScreenId}/automation/$ { AutomationId}` |

## Condition keys for Amazon Honeycode

Honeycode has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.